// variables
var dropArea = document.getElementById('dropArea');
var canvas = document.querySelector('canvas');
var context = canvas.getContext('2d');
var destinationUrl = "/upload";
var result = document.getElementById('result');
var list = [];
var totalSize = 0;
var totalProgress = 0;
var fileName = document.getElementById("file-name");
var fileSize = document.getElementById("file-size");
var fileProgress = document.getElementById("file-progress");
var filePath = document.getElementById("filePath");

var file;
// main initialization
(function() {

	// init handlers
	function initHandlers() {
		dropArea.addEventListener('drop', handleDrop, false);
		dropArea.addEventListener('dragover', handleDragOver, false);
		filePath.addEventListener("change", fileSelected, false)
	}

	function fileSelected(event) {
		event.stopPropagation();
		event.preventDefault();

		// document.getElementById('myForm').submit();
		var filePath = document.getElementById("filePath");
		var filelist = filePath.files;
		if (filelist.length == 0) {
			alert("没有选择到文件");
			return;
		}

		var file = filelist[0];
        
		totalSize = file.size;
        totalProgress = 0;

		uploadFile(file, "");

	}

	// draw progress
	function drawProgress(progress) {
		context.clearRect(0, 0, canvas.width, canvas.height); // clear context

		context.beginPath();
		context.strokeStyle = '#69d621';
		context.fillStyle = '#69d621';
		context.fillRect(0, 0, progress * 500, 3);
		context.closePath();

		fileProgress.innerHTML = Math.floor(progress * 100) + '%';
	}

	// drag over
	function handleDragOver(event) {
		event.stopPropagation();
		event.preventDefault();

		dropArea.className = 'hover';
	}

	// drag drop
	function handleDrop(event) {
		event.stopPropagation();
		event.preventDefault();

		processFiles(event.dataTransfer.files);
	}

	// process bunch of files
	function processFiles(filelist) {
		if (!filelist || !filelist.length || list.length)
			return;

		if (filelist.length > 1) {
			result.innerHTML = '<div class="f">文件只能同时上传一个</div>';
			return;
		}
		file = filelist[0]
		totalSize = 0;
		totalProgress = 0;
		result.textContent = '';

		list.push(filelist[0]);
		totalSize += filelist[0].size;
		uploadNext();
	}

	// on complete - start next file
	function handleComplete(size) {
		totalProgress += size;
		drawProgress(totalProgress / totalSize);
		uploadNext();
	}

	// update progress
	function handleProgress(event) {
		var progress = totalProgress + event.loaded;
		drawProgress(progress / totalSize);
	}

	// upload file
	function uploadFile(file, status) {

		fileName.innerHTML = file.name;
		fileSize.innerHTML = file.size + "B";
		// prepare XMLHttpRequest
		var xhr = new XMLHttpRequest();
		xhr.open('POST', destinationUrl);
		xhr.onload = function() {
			result.innerHTML = this.responseText;
			handleComplete(file.size);
		};
		xhr.onerror = function() {
			result.textContent = this.responseText;
			handleComplete(file.size);
		};
		xhr.upload.onprogress = function(event) {
			handleProgress(event);
		}
		xhr.upload.onloadstart = function(event) {
		}

		// prepare FormData
		var formData = new FormData();
		formData.append('myfile', file);
		xhr.send(formData);
	}

	// upload next file
	function uploadNext() {
		if (list.length) {
			// count.textContent = list.length - 1;
			dropArea.className = 'uploading';
			var nextFile = list.shift();

			if (nextFile.size >= 262144000) { // 256000kb
				result.innerHTML = '<div class="f">文件过大 (max filesize exceeded)</div>';
				handleComplete(nextFile.size);
			} else {
				uploadFile(nextFile, status);
			}
		} else {
			dropArea.className = '';
		}
	}

	initHandlers();
})();